@@ -286,15 +286,28 @@ def main():
 
     # Update ruuvi data every 5 minutes
     schedule.every(5).minutes.do(get_ruuvi_data)
+    def test_schedule():
+        print("Testing schedule")
+
+    schedule.every(1).minutes.do(test_schedule)
+
+    print("Starting schedule thread...")
 
     def run_schedule():
+            print("Running schedule")
             schedule.run_pending()
+            print("Sleeping for 1 second")
             time.sleep(1)
-    
-    thread = threading.Thread(target=run_schedule, daemon=True, name="schedule_thread")
-    thread.start()
 
-    application.run_polling()
+    def run_application():
+        print("Running application")
+        application.run_polling()
+    
+    schedule_thread = threading.Thread(target=run_schedule, daemon=True, name="schedule_thread")
+    schedule_thread.start()
+
+    schedule_thread = threading.Thread(target=run_application, daemon=True, name="application_thread")
+    schedule_thread.start()
 
 
 if __name__ == "__main__":
